@@ -5,6 +5,7 @@
 # Distributed under the BSD license, see LICENSE.txt
 from .cssselectpatch import JQueryTranslator
 from .openers import url_opener
+from .text import extract_text
 from copy import deepcopy
 from lxml import etree
 import lxml.html
@@ -231,7 +232,7 @@ class PyQuery(list):
             if hasattr(html, 'close'):
                 try:
                     html.close()
-                except:
+                except Exception:
                     pass
 
         else:
@@ -963,7 +964,7 @@ class PyQuery(list):
     # CORE UI EFFECTS #
     ###################
     def hide(self):
-        """remove display:none to elements style
+        """Remove display:none to elements style:
 
             >>> print(PyQuery('<div style="display:none;"/>').hide())
             <div style="display: none"/>
@@ -972,7 +973,7 @@ class PyQuery(list):
         return self.css('display', 'none')
 
     def show(self):
-        """add display:block to elements style
+        """Add display:block to elements style:
 
             >>> print(PyQuery('<div />').show())
             <div style="display: block"/>
@@ -1130,13 +1131,17 @@ class PyQuery(list):
             e0.tail = ''
         return etree.tostring(e0, encoding=text_type, method=method)
 
-    def text(self, value=no_default):
+    def text(self, value=no_default, **kwargs):
         """Get or set the text representation of sub nodes.
 
         Get the text value::
 
             >>> doc = PyQuery('<div><span>toto</span><span>tata</span></div>')
             >>> print(doc.text())
+            tototata
+            >>> doc = PyQuery('''<div><span>toto</span>
+            ...               <span>tata</span></div>''')
+            >>> print(doc.text())
             toto tata
 
         Set the text value::
@@ -1151,20 +1156,7 @@ class PyQuery(list):
         if value is no_default:
             if not self:
                 return ''
-
-            text = []
-
-            def add_text(tag, no_tail=False):
-                if tag.text and not isinstance(tag, lxml.etree._Comment):
-                    text.append(tag.text)
-                for child in tag.getchildren():
-                    add_text(child)
-                if not no_tail and tag.tail:
-                    text.append(tag.tail)
-
-            for tag in self:
-                add_text(tag, no_tail=True)
-            return ' '.join([t.strip() for t in text if t.strip()])
+            return ' '.join(extract_text(tag, **kwargs) for tag in self)
 
         for tag in self:
             for child in tag.getchildren():
@@ -1383,7 +1375,7 @@ class PyQuery(list):
 
     @with_camel_case_alias
     def replace_with(self, value):
-        """replace nodes by value::
+        """replace nodes by value:
 
             >>> doc = PyQuery("<html><div /></html>")
             >>> node = PyQuery("<span />")
@@ -1435,12 +1427,14 @@ class PyQuery(list):
     def remove(self, expr=no_default):
         """Remove nodes:
 
-         >>> h = '<div>Maybe <em>she</em> does <strong>NOT</strong> know</div>'
-         >>> d = PyQuery(h)
-         >>> d('strong').remove()
-         [<strong>]
-         >>> print(d)
-         <div>Maybe <em>she</em> does   know</div>
+             >>> h = (
+             ... '<div>Maybe <em>she</em> does <strong>NOT</strong> know</div>'
+             ... )
+             >>> d = PyQuery(h)
+             >>> d('strong').remove()
+             [<strong>]
+             >>> print(d)
+             <div>Maybe <em>she</em> does   know</div>
         """
         if expr is no_default:
             for tag in self:
